@@ -174,14 +174,15 @@ class Predict(Module):
             parsed_outputs = {"output": text}
 
         # Validate outputs if signature available
-        if self.signature and parsed_outputs:
+        # Note: Check parsed_outputs is not None, not just truthy (empty dict is falsy but valid)
+        if self.signature and parsed_outputs is not None:
             try:
                 validated_outputs = self.signature.validate_outputs(**parsed_outputs)
             except Exception:
                 # If validation fails, keep parsed outputs
                 validated_outputs = parsed_outputs
         else:
-            validated_outputs = parsed_outputs
+            validated_outputs = parsed_outputs if parsed_outputs is not None else {}
 
         # Create prediction with optional prompt capture
         metadata = {
